CREATE FUNCTION [dbo].[FN_ConvertLanguageValues] 
( 
    @language varchar ( 100 ) , 
    @field varchar ( 20 ) 
) 
RETURNS @List TABLE 
( 
    row [int] IDENTITY 
    ( 1 , 
        1 ) 
    NOT NULL , 
    item varchar ( 2000 ) 
) 
/**
examples
posible input values Months,Days,ShortMonths
Returns all values for the language selected
select * from dbo.FN_ConvertLanguageValues('Dutch','Months')
select * from dbo.FN_ConvertLanguageValues('Dutch','Days')
select * from dbo.FN_ConvertLanguageValues('Dutch','ShortMonths')

'Direct query example returns current month for current date
select item as dutchmonth from dbo.FN_ConvertLanguageValues('Dutch','months') where row = DATEPART(m, getdate()) 
 
'Select the dayname for the current day
select item as dutchday from dbo.FN_ConvertLanguageValues('Dutch','days') where row = DATEPART(weekday, getdate()) 

'Table Query Examples
select myfield,(select item as dutchmonth from dbo.FN_ConvertLanguageValues('Dutch','months') where row = DATEPART(m, mydatefield)) as dutchmonth from mytable
select myfield,(select item as dutchday from dbo.FN_ConvertLanguageValues('Dutch','days') where row = DATEPART(weekday, mydatefield)) as dutchday from mytable

****/ BEGIN DECLARE @sItem varchar ( 2000 ) , 
@sInputList varchar ( 2000 ) , 
@sDelimiter char ( 1 ) = ',' SET @sItem = '' IF @field = 'Months' BEGIN SET @sInputList = 
( 
    SELECT Months FROM sys.sysLanguages WHERE alias = @language 
) 
END IF @field = 'Days' BEGIN SET @sInputList = 
( 
    SELECT Days FROM sys.sysLanguages WHERE alias = @language 
) 
END IF @field = 'ShortMonths' BEGIN SET @sInputList = 
( 
    SELECT shortmonths FROM sys.sysLanguages WHERE alias = @language 
) 
END WHILE charindex 
( 
    @sDelimiter , 
    @sInputList , 
    0 
) <> 0 BEGIN SET @sItem = rtrim 
( ltrim 
    ( substring 
        ( @sInputList , 
            1 , 
            charindex 
            ( @sDelimiter , 
                @sInputList , 
                0 ) - 1 ) 
    ) 
) 
SET @sInputList = rtrim 
( ltrim 
    ( substring 
        ( @sInputList , 
            charindex 
            ( @sDelimiter , 
                @sInputList , 
                0 ) + len ( @sDelimiter ) , 
            len ( @sInputList ) ) 
    ) 
) 
INSERT INTO @List SELECT replace 
( 
    @sItem , 
    LEFT 
    ( @sItem , 
        1 ) , 
    upper 
    ( LEFT 
        ( @sItem , 
            1 ) 
    ) 
) 
END INSERT INTO @List SELECT @sInputList RETURN END - 

/*  **** Helper Functions */ CREATE FUNCTION dbo. [MonthNames] 
( 
    @Language varchar ( 50 ) , 
    @Date datetime 
) 
RETURNS varchar ( 50 ) 
--Example
--select dbo.monthNames('Dutch',GetDATE()) as monthname
BEGIN DECLARE @rValue varchar ( 50 ) SET @rValue = 
( 
    SELECT item AS dutchmonth FROM dbo.FN_ConvertLanguageValues 
    ( @Language , 
        'months' ) 
    WHERE row = datepart 
    ( m , 
        @date ) 
) 
RETURN @rValue END CREATE FUNCTION dbo. [DayNames] 
( 
    @Language varchar ( 50 ) , 
    @Date datetime 
) 
RETURNS varchar ( 50 ) 
--Example
--select dbo.dayNames('Dutch',GetDATE()) as dayname
BEGIN DECLARE @rValue varchar ( 50 ) DECLARE @datefirst int SET @dateFirst = 
( 
    SELECT datefirst FROM sys.syslanguages WHERE alias = @language 
) 
IF @Datefirst = 1 BEGIN SET @rValue = 
( 
    SELECT item FROM 
    ( 
        SELECT item , 
        CASE WHEN row = 1 THEN 7 WHEN row = 2 THEN 1 WHEN row = 3 THEN 2 WHEN row = 4 THEN 3 WHEN row = 5 THEN 4 WHEN row = 6 THEN 5 WHEN row = 7 THEN 1 END AS row FROM dbo.FN_ConvertLanguageValues 
        ( @Language , 
            'Days' ) 
    ) 
    AS d1 WHERE row = datepart 
    ( weekDay , 
        @date ) 
) 
END ELSE BEGIN SET @rValue = 
( 
    SELECT item AS dutchmonth FROM dbo.FN_ConvertLanguageValues 
    ( @Language , 
        'Days' ) 
    WHERE row = datepart 
    ( weekDay , 
        @date ) 
) 
END RETURN @rValue END